==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="ru">
<defaultcodec></defaultcodec>
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="49"/>
        <source>Qmmp Analyzer</source>
        <translation>Анализатор Qmmp</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Настройки  анализатора</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Show peaks</source>
        <translation>Показывать пики</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Analyzer falloff:</source>
        <translation>Падение анализатора:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Slowest</source>
        <translation>Самое медленное</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Slow</source>
        <translation>Медленное</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="112"/>
        <source>Fast</source>
        <translation>Быстрое</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Fastest</source>
        <translation>Самое быстрое</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Peaks falloff:</source>
        <translation>Падение пиков:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="125"/>
        <source>Refresh rate:</source>
        <translation>Частота обновления:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>50 FPS</source>
        <translation>50 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>25 FPS</source>
        <translation>25 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>10 FPS</source>
        <translation>10 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>5 FPS</source>
        <translation>5 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="177"/>
        <source>Peaks:</source>
        <translation>Пики:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #1:</source>
        <translation>Анализатор #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Background:</source>
        <translation>Фон:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Analyzer #2:</source>
        <translation>Анализатор #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>Analyzer #3:</source>
        <translation>Анализатор #3:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="351"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Анализатор</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Об анализаторе (модуле визуализации)</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Модуль анализатора для Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Visual/analyzer/translations/analyzer_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="48"/>
        <source>Qmmp Analyzer</source>
        <translation>Анализатор Qmmp</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Настройки  анализатора</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Show peaks</source>
        <translation>Показывать пики</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Analyzer falloff:</source>
        <translation>Падение анализатора:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Slowest</source>
        <translation>Самое медленное</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Slow</source>
        <translation>Медленное</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <location filename="../settingsdialog.ui" line="112"/>
        <source>Fast</source>
        <translation>Быстрое</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Fastest</source>
        <translation>Самое быстрое</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Peaks falloff:</source>
        <translation>Падение пиков:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="125"/>
        <source>Refresh rate:</source>
        <translation>Частота обновления:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>50 FPS</source>
        <translation>50 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>25 FPS</source>
        <translation>25 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>10 FPS</source>
        <translation>10 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>5 FPS</source>
        <translation>5 кад/с</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Colors</source>
        <translation>Цвета</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="177"/>
        <source>Peaks:</source>
        <translation>Пики:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #1:</source>
        <translation>Анализатор #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Background:</source>
        <translation>Фон:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Analyzer #2:</source>
        <translation>Анализатор #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>Analyzer #3:</source>
        <translation>Анализатор #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Анализатор</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Об анализаторе (модуле визуализации)</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Модуль анализатора для Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
